Error

Enum Error 

#[non_exhaustive]
pub enum Error { Invalid, OutOfBounds, StorageError, WriteProtected, InvalidPartition { expected_size: usize, expected_type: PartitionType, }, InvalidState, InvalidArgument, NotSupported, InvalidImage, }
Errors which can be returned.

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.


Invalid

The partition table is invalid or doesn’t contain a needed partition.



OutOfBounds

An operation tries to access data that is out of bounds.



StorageError

An error which originates from the embedded-storage implementation.



WriteProtected

The partition is write protected.



InvalidPartition

The partition is invalid.

Fields

expected_size: usize
expected_type: PartitionType


InvalidState

Invalid state



InvalidArgument

The given argument is invalid.



NotSupported

The operation is not supported for this partition (e.g. as_nor_flash on an encrypted partition).



InvalidImage

The partition does not contain a valid application or bootloader image.