FlashRegion

Struct FlashRegion 

pub struct FlashRegion<'a, 'd> { /* private fields */ }
A flash region is a “view” into the partition.

It allows to read and write to the partition without the need to account for the partition offset.

Implementations

Source

impl<'a, 'd> FlashRegion<'a, 'd>

pub fn partition_size(&self) -> usize

Returns the size of the partition in bytes.

pub fn read(&mut self, offset: u32, bytes: &mut [u8]) -> Result<(), Error>

Read bytes from the partition.

pub fn write(&mut self, offset: u32, bytes: &[u8]) -> Result<(), Error>

Write bytes to the partition.

pub fn capacity(&self) -> usize

Returns the size of the partition in bytes.

pub fn erase(&mut self, from: u32, to: u32) -> Result<(), Error>

Erase flash in the partition from from up to but not including to.

Addresses are relative to the partition start.